@@ -12,6 +12,9 @@ function expandTable(newsitems,batch) {
 
 var news = [ // date, text
 
+  ["November 7, 2025",
+   "New patch release: slepc-3.24.1 includes miscellaneous fixes, mainly related to documentation."],
+
   ["September 30, 2025",
    "SLEPc 3.24 has been released. The distribution file is available at the <a href='https://slepc.upv.es/release/installation/download.html'>download page</a>. See a list of <a href='https://gitlab.com/slepc/slepc/-/blob/main/CHANGELOG.md'>changes</a> in this version."],
 
