@@ -178,10 +178,10 @@ static PetscErrorCode rescale_eig(EPS eps,PetscInt nv)
       PetscCall(RGIntervalGetEndpoints(eps->rg,&a,&b,&c,&d));
       if (ctx->quad == EPS_CISS_QUADRULE_CHEBYSHEV) {
         for (i=0;i<nv;i++) {
-          if (c==d) eps->eigr[i] = ((b-a)*(eps->eigr[i]+1.0)/2.0+a)*rgscale;
+          if (c==d) eps->eigr[i] = ((eps->eigr[i]+1.0)*(b-a)/2.0+a)*rgscale;
           if (a==b) {
 #if defined(PETSC_USE_COMPLEX)
-            eps->eigr[i] = ((d-c)*(eps->eigr[i]+1.0)/2.0+c)*rgscale*PETSC_i;
+            eps->eigr[i] = ((eps->eigr[i]+1.0)*(d-c)/2.0+c)*rgscale*PETSC_i;
 #else
             SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP,"Integration points on a vertical line require complex arithmetic");
 #endif
@@ -225,6 +225,7 @@ static PetscErrorCode EPSSetUp_CISS(EPS eps)
   PetscFunctionBegin;
   EPSCheckNotStructured(eps);
   if (eps->ncv==PETSC_DETERMINE) {
+    if (eps->nev==0) eps->nev = 1;
     eps->ncv = ctx->L_max*ctx->M;
     if (eps->ncv>eps->n) {
       eps->ncv = eps->n;
@@ -232,7 +233,7 @@ static PetscErrorCode EPSSetUp_CISS(EPS eps)
       PetscCheck(ctx->L_max,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"Cannot adjust solver parameters, try setting a smaller value of M (moment size)");
     }
   } else {
-    PetscCall(EPSSetDimensions_Default(eps,eps->nev,&eps->ncv,&eps->mpd));
+    PetscCall(EPSSetDimensions_Default(eps,&eps->nev,&eps->ncv,&eps->mpd));
     ctx->L_max = eps->ncv/ctx->M;
     if (!ctx->L_max) {
       ctx->L_max = 1;
@@ -716,33 +717,35 @@ static PetscErrorCode EPSCISSSetSizes_CISS(EPS eps,PetscInt ip,PetscInt bs,Petsc
    Logically Collective
 
    Input Parameters:
-+  eps   - the eigenproblem solver context
-.  ip    - number of integration points
-.  bs    - block size
-.  ms    - moment size
-.  npart - number of partitions when splitting the communicator
-.  bsmax - max block size
--  realmats - A and B are real
++  eps      - the linear eigensolver context
+.  ip       - number of integration points
+.  bs       - block size
+.  ms       - moment size
+.  npart    - number of partitions when splitting the communicator
+.  bsmax    - max block size
+-  realmats - $A$ and $B$ are real
 
    Options Database Keys:
-+  -eps_ciss_integration_points - Sets the number of integration points
-.  -eps_ciss_blocksize - Sets the block size
-.  -eps_ciss_moments - Sets the moment size
-.  -eps_ciss_partitions - Sets the number of partitions
-.  -eps_ciss_maxblocksize - Sets the maximum block size
--  -eps_ciss_realmats - A and B are real
++  -eps_ciss_integration_points \<ip\> - sets the number of integration points
+.  -eps_ciss_blocksize \<bs\>          - sets the block size
+.  -eps_ciss_moments \<ms\>            - sets the moment size
+.  -eps_ciss_partitions \<npart\>      - sets the number of partitions
+.  -eps_ciss_maxblocksize \<bsmax\>    - sets the maximum block size
+-  -eps_ciss_realmats                  - $A$ and $B$ are real
 
-   Note:
-   For all integer arguments, you can use PETSC_CURRENT to keep the current value, and
-   PETSC_DETERMINE to set them to a default value.
+   Notes:
+   For all integer arguments, you can use `PETSC_CURRENT` to keep the current value, and
+   `PETSC_DETERMINE` to set them to a default value.
 
-   The default number of partitions is 1. This means the internal KSP object is shared
-   among all processes of the EPS communicator. Otherwise, the communicator is split
-   into npart communicators, so that npart KSP solves proceed simultaneously.
+   The default number of partitions is 1. This means the internal `KSP` object is shared
+   among all processes of the `EPS` communicator. Otherwise, the communicator is split
+   into `npart` communicators, so that `npart` `KSP` solves proceed simultaneously.
+
+   For a detailed description of the parameters see {cite:p}`Mae16`.
 
    Level: advanced
 
-.seealso: EPSCISSGetSizes()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSGetSizes()`, `EPSCISSSetThreshold()`, `EPSCISSSetRefinement()`
 @*/
 PetscErrorCode EPSCISSSetSizes(EPS eps,PetscInt ip,PetscInt bs,PetscInt ms,PetscInt npart,PetscInt bsmax,PetscBool realmats)
 {
@@ -778,7 +781,7 @@ static PetscErrorCode EPSCISSGetSizes_CISS(EPS eps,PetscInt *ip,PetscInt *bs,Pet
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameters:
 +  ip    - number of integration points
@@ -786,11 +789,11 @@ static PetscErrorCode EPSCISSGetSizes_CISS(EPS eps,PetscInt *ip,PetscInt *bs,Pet
 .  ms    - moment size
 .  npart - number of partitions when splitting the communicator
 .  bsmax - max block size
--  realmats - A and B are real
+-  realmats - $A$ and $B$ are real
 
    Level: advanced
 
-.seealso: EPSCISSSetSizes()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSSetSizes()`
 @*/
 PetscErrorCode EPSCISSGetSizes(EPS eps,PetscInt *ip,PetscInt *bs,PetscInt *ms,PetscInt *npart,PetscInt *bsmax,PetscBool *realmats)
 {
@@ -827,21 +830,23 @@ static PetscErrorCode EPSCISSSetThreshold_CISS(EPS eps,PetscReal delta,PetscReal
    Logically Collective
 
    Input Parameters:
-+  eps   - the eigenproblem solver context
++  eps   - the linear eigensolver context
 .  delta - threshold for numerical rank
 -  spur  - spurious threshold (to discard spurious eigenpairs)
 
    Options Database Keys:
-+  -eps_ciss_delta - Sets the delta
--  -eps_ciss_spurious_threshold - Sets the spurious threshold
++  -eps_ciss_delta \<delta\>             - sets the delta
+-  -eps_ciss_spurious_threshold \<spur\> - sets the spurious threshold
 
-   Note:
-   PETSC_CURRENT can be used to preserve the current value of any of the
-   arguments, and PETSC_DETERMINE to set them to a default value.
+   Notes:
+   `PETSC_CURRENT` can be used to preserve the current value of any of the
+   arguments, and `PETSC_DETERMINE` to set them to a default value.
+
+   For a detailed description of the parameters see {cite:p}`Mae16`.
 
    Level: advanced
 
-.seealso: EPSCISSGetThreshold()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSGetThreshold()`, `EPSCISSSetSizes()`, `EPSCISSSetRefinement()`
 @*/
 PetscErrorCode EPSCISSSetThreshold(EPS eps,PetscReal delta,PetscReal spur)
 {
@@ -870,7 +875,7 @@ static PetscErrorCode EPSCISSGetThreshold_CISS(EPS eps,PetscReal *delta,PetscRea
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameters:
 +  delta - threshold for numerical rank
@@ -878,7 +883,7 @@ static PetscErrorCode EPSCISSGetThreshold_CISS(EPS eps,PetscReal *delta,PetscRea
 
    Level: advanced
 
-.seealso: EPSCISSSetThreshold()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSSetThreshold()`
 @*/
 PetscErrorCode EPSCISSGetThreshold(EPS eps,PetscReal *delta,PetscReal *spur)
 {
@@ -915,21 +920,23 @@ static PetscErrorCode EPSCISSSetRefinement_CISS(EPS eps,PetscInt inner,PetscInt
    Logically Collective
 
    Input Parameters:
-+  eps    - the eigenproblem solver context
++  eps    - the linear eigensolver context
 .  inner  - number of iterative refinement iterations (inner loop)
 -  blsize - number of iterative refinement iterations (blocksize loop)
 
    Options Database Keys:
-+  -eps_ciss_refine_inner - Sets number of inner iterations
--  -eps_ciss_refine_blocksize - Sets number of blocksize iterations
++  -eps_ciss_refine_inner \<inner\>      - sets number of inner iterations
+-  -eps_ciss_refine_blocksize \<blsize\> - sets number of blocksize iterations
 
-   Note:
-   PETSC_CURRENT can be used to preserve the current value of any of the
-   arguments, and PETSC_DETERMINE to set them to a default of 0.
+   Notes:
+   `PETSC_CURRENT` can be used to preserve the current value of any of the
+   arguments, and `PETSC_DETERMINE` to set them to a default of 0 (no refinement).
+
+   For a detailed description of the parameters see {cite:p}`Mae16`.
 
    Level: advanced
 
-.seealso: EPSCISSGetRefinement()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSGetRefinement()`, `EPSCISSSetSizes()`, `EPSCISSSetThreshold()`
 @*/
 PetscErrorCode EPSCISSSetRefinement(EPS eps,PetscInt inner,PetscInt blsize)
 {
@@ -958,7 +965,7 @@ static PetscErrorCode EPSCISSGetRefinement_CISS(EPS eps,PetscInt *inner,PetscInt
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameters:
 +  inner  - number of iterative refinement iterations (inner loop)
@@ -966,7 +973,7 @@ static PetscErrorCode EPSCISSGetRefinement_CISS(EPS eps,PetscInt *inner,PetscInt
 
    Level: advanced
 
-.seealso: EPSCISSSetRefinement()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSSetRefinement()`
 @*/
 PetscErrorCode EPSCISSGetRefinement(EPS eps, PetscInt *inner, PetscInt *blsize)
 {
@@ -989,20 +996,29 @@ static PetscErrorCode EPSCISSSetUseST_CISS(EPS eps,PetscBool usest)
 
 /*@
    EPSCISSSetUseST - Sets a flag indicating that the CISS solver will
-   use the ST object for the linear solves.
+   use the `ST` object for the linear solves.
 
    Logically Collective
 
    Input Parameters:
-+  eps    - the eigenproblem solver context
--  usest  - boolean flag to use the ST object or not
++  eps    - the linear eigensolver context
+-  usest  - boolean flag to use the `ST` object or not
 
-   Options Database Keys:
-.  -eps_ciss_usest <bool> - whether the ST object will be used or not
+   Options Database Key:
+.  -eps_ciss_usest - whether the `ST` object will be used or not
+
+   Note:
+   When this option is set, the linear solves can be configured by
+   setting options for the `KSP` object obtained with `STGetKSP()`.
+   Otherwise, several `KSP` objects are created, which can be accessed
+   with `EPSCISSGetKSPs()`.
+
+   The default is to use the `ST`, unless several partitions have been
+   specified, see `EPSCISSSetSizes()`.
 
    Level: advanced
 
-.seealso: EPSCISSGetUseST()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSGetUseST()`, `EPSCISSSetSizes()`, `EPSCISSGetKSPs()`, `STGetKSP()`
 @*/
 PetscErrorCode EPSCISSSetUseST(EPS eps,PetscBool usest)
 {
@@ -1023,20 +1039,20 @@ static PetscErrorCode EPSCISSGetUseST_CISS(EPS eps,PetscBool *usest)
 }
 
 /*@
-   EPSCISSGetUseST - Gets the flag for using the ST object
+   EPSCISSGetUseST - Gets the flag for using the `ST` object
    in the CISS solver.
 
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
-   Output Parameters:
-.  usest - boolean flag indicating if the ST object is being used
+   Output Parameter:
+.  usest - boolean flag indicating if the `ST` object is being used
 
    Level: advanced
 
-.seealso: EPSCISSSetUseST()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSSetUseST()`
 @*/
 PetscErrorCode EPSCISSGetUseST(EPS eps,PetscBool *usest)
 {
@@ -1065,22 +1081,21 @@ static PetscErrorCode EPSCISSSetQuadRule_CISS(EPS eps,EPSCISSQuadRule quad)
    Logically Collective
 
    Input Parameters:
-+  eps  - the eigenproblem solver context
--  quad - the quadrature rule
++  eps  - the linear eigensolver context
+-  quad - the quadrature rule, see `EPSCISSQuadRule` for possible values
 
    Options Database Key:
-.  -eps_ciss_quadrule - Sets the quadrature rule (either 'trapezoidal' or
-                           'chebyshev')
+.  -eps_ciss_quadrule \<quad\> - sets the quadrature rule, either `trapezoidal` or `chebyshev`
 
    Notes:
-   By default, the trapezoidal rule is used (EPS_CISS_QUADRULE_TRAPEZOIDAL).
+   By default, the trapezoidal rule is used (`EPS_CISS_QUADRULE_TRAPEZOIDAL`).
 
-   If the 'chebyshev' option is specified (EPS_CISS_QUADRULE_CHEBYSHEV), then
+   If the `chebyshev` option is specified (`EPS_CISS_QUADRULE_CHEBYSHEV`), then
    Chebyshev points are used as quadrature points.
 
    Level: advanced
 
-.seealso: EPSCISSGetQuadRule(), EPSCISSQuadRule
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSGetQuadRule()`, `EPSCISSQuadRule`
 @*/
 PetscErrorCode EPSCISSSetQuadRule(EPS eps,EPSCISSQuadRule quad)
 {
@@ -1106,14 +1121,14 @@ static PetscErrorCode EPSCISSGetQuadRule_CISS(EPS eps,EPSCISSQuadRule *quad)
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
-   Output Parameters:
+   Output Parameter:
 .  quad - quadrature rule
 
    Level: advanced
 
-.seealso: EPSCISSSetQuadRule() EPSCISSQuadRule
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSSetQuadRule()`, `EPSCISSQuadRule`
 @*/
 PetscErrorCode EPSCISSGetQuadRule(EPS eps,EPSCISSQuadRule *quad)
 {
@@ -1142,22 +1157,22 @@ static PetscErrorCode EPSCISSSetExtraction_CISS(EPS eps,EPSCISSExtraction extrac
    Logically Collective
 
    Input Parameters:
-+  eps        - the eigenproblem solver context
--  extraction - the extraction technique
++  eps        - the linear eigensolver context
+-  extraction - the extraction technique, see `EPSCISSExtraction` for possible values
 
    Options Database Key:
-.  -eps_ciss_extraction - Sets the extraction technique (either 'ritz' or
-                           'hankel')
+.  -eps_ciss_extraction \<extraction\> - sets the extraction technique, either `ritz` or `hankel`
 
    Notes:
-   By default, the Rayleigh-Ritz extraction is used (EPS_CISS_EXTRACTION_RITZ).
+   By default, the Rayleigh-Ritz extraction is used (`EPS_CISS_EXTRACTION_RITZ`),
+   see {cite:p}`Sak07`.
 
-   If the 'hankel' option is specified (EPS_CISS_EXTRACTION_HANKEL), then
-   the Block Hankel method is used for extracting eigenpairs.
+   If the `hankel` option is specified (`EPS_CISS_EXTRACTION_HANKEL`), then
+   the block Hankel method is used for extracting eigenpairs {cite:p}`Sak03`.
 
    Level: advanced
 
-.seealso: EPSCISSGetExtraction(), EPSCISSExtraction
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSGetExtraction()`, `EPSCISSExtraction`
 @*/
 PetscErrorCode EPSCISSSetExtraction(EPS eps,EPSCISSExtraction extraction)
 {
@@ -1183,14 +1198,14 @@ static PetscErrorCode EPSCISSGetExtraction_CISS(EPS eps,EPSCISSExtraction *extra
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
-   Output Parameters:
+   Output Parameter:
 .  extraction - extraction technique
 
    Level: advanced
 
-.seealso: EPSCISSSetExtraction() EPSCISSExtraction
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSSetExtraction()`, `EPSCISSExtraction`
 @*/
 PetscErrorCode EPSCISSGetExtraction(EPS eps,EPSCISSExtraction *extraction)
 {
@@ -1250,20 +1265,20 @@ static PetscErrorCode EPSCISSGetKSPs_CISS(EPS eps,PetscInt *nsolve,KSP **ksp)
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver solver
+.  eps - the linear eigensolver context
 
    Output Parameters:
 +  nsolve - number of solver objects
 -  ksp - array of linear solver object
 
-   Notes:
-   The number of KSP solvers is equal to the number of integration points divided by
-   the number of partitions. This value is halved in the case of real matrices with
-   a region centered at the real axis.
+   Note:
+   The number of `KSP` solvers is equal to the number of integration points divided by
+   the number of partitions, see `EPSCISSSetSizes()`. This value is halved in the case
+   of real matrices with a region centered at the real axis.
 
    Level: advanced
 
-.seealso: EPSCISSSetSizes()
+.seealso: [](ch:eps), `EPSCISS`, `EPSCISSSetSizes()`
 @*/
 PetscErrorCode EPSCISSGetKSPs(EPS eps,PetscInt *nsolve,KSP **ksp)
 {
@@ -1286,7 +1301,7 @@ static PetscErrorCode EPSReset_CISS(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode EPSSetFromOptions_CISS(EPS eps,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode EPSSetFromOptions_CISS(EPS eps,PetscOptionItems PetscOptionsObject)
 {
   PetscReal         r3,r4;
   PetscInt          i,i1,i2,i3,i4,i5,i6,i7;
@@ -1420,6 +1435,28 @@ static PetscErrorCode EPSSetDefaultST_CISS(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSCISS - EPSCISS = "ciss" - A contour integral eigensolver based on the
+   Sakurai-Sugiura scheme.
+
+   Notes:
+   This solver is based on the numerical contour integration idea
+   proposed initially by {cite:t}`Sak03` and improved later by adding
+   a Rayleigh-Ritz projection step {cite:p}`Sak07`.
+
+   Contour integral methods are able to compute all eigenvalues
+   lying inside a region of the complex plane. Use `EPSGetRG()` to
+   specify the region. However, the computational cost is usually high
+   because multiple linear systems must be solved. For this, we can
+   use the `KSP` object inside `ST`, or several independent `KSP`s,
+   see `EPSCISSSetUseST()`.
+
+   Details of the implementation in SLEPc can be found in {cite:p}`Mae16`.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`, `EPSGetRG()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_CISS(EPS eps)
 {
   EPS_CISS       *ctx = (EPS_CISS*)eps->data;
