@@ -22,6 +22,7 @@ static PetscErrorCode EPSSetUp_ARPACK(EPS eps)
   PetscFunctionBegin;
   EPSCheckDefinite(eps);
   EPSCheckNotStructured(eps);
+  if (eps->nev==0) eps->nev = 1;
   if (eps->ncv!=PETSC_DETERMINE) {
     PetscCheck(eps->ncv>=eps->nev+2,PetscObjectComm((PetscObject)eps),PETSC_ERR_ARG_OUTOFRANGE,"The value of ncv must be at least nev+2");
   } else eps->ncv = PetscMin(PetscMax(20,2*eps->nev+1),eps->n); /* set default value of ncv */
@@ -274,6 +275,17 @@ static PetscErrorCode EPSDestroy_ARPACK(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSARPACK - EPSARPACK = "arpack" - A wrapper to ARPACK {cite:p}`Leh98`.
+
+   Note:
+   We recommend using `EPSKRYLOVSCHUR` instead of this one, because both
+   methods are mathematically equivalent and Krylov-Schur may be more robust.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_ARPACK(EPS eps)
 {
   EPS_ARPACK     *ctx;
