@@ -179,6 +179,7 @@ static PetscErrorCode EPSSetUp_PRIMME(EPS eps)
   PetscFunctionBegin;
   EPSCheckHermitianDefinite(eps);
   EPSCheckNotStructured(eps);
+  if (eps->nev==0) eps->nev = 1;
   PetscCallMPI(MPI_Comm_size(PetscObjectComm((PetscObject)eps),&numProcs));
   PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)eps),&procID));
 
@@ -401,7 +402,7 @@ static PetscErrorCode EPSView_PRIMME(EPS eps,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode EPSSetFromOptions_PRIMME(EPS eps,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode EPSSetFromOptions_PRIMME(EPS eps,PetscOptionItems PetscOptionsObject)
 {
   EPS_PRIMME      *ctx = (EPS_PRIMME*)eps->data;
   PetscInt        bs;
@@ -440,24 +441,26 @@ static PetscErrorCode EPSPRIMMESetBlockSize_PRIMME(EPS eps,PetscInt bs)
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
++  eps - the linear eigensolver context
 -  bs - block size
 
    Options Database Key:
-.  -eps_primme_blocksize - Sets the max allowed block size value
+.  -eps_primme_blocksize \<bs\> - sets the maximum allowed block size
 
    Notes:
-   If the block size is not set, the value established by primme_initialize
+   If the block size is not set, the value established by `primme_initialize`
    is used.
 
    The user should set the block size based on the architecture specifics
    of the target computer, as well as any a priori knowledge of multiplicities.
-   The code does NOT require bs > 1 to find multiple eigenvalues. For some
-   methods, keeping bs = 1 yields the best overall performance.
+   The code does NOT require `bs` > 1 to find multiple eigenvalues. For some
+   methods, keeping `bs` = 1 yields the best overall performance.
+
+   See the documentation of PRIMME {cite:p}`Sta10` for details.
 
    Level: advanced
 
-.seealso: EPSPRIMMEGetBlockSize()
+.seealso: [](ch:eps), `EPSPRIMME`, `EPSPRIMMEGetBlockSize()`
 @*/
 PetscErrorCode EPSPRIMMESetBlockSize(EPS eps,PetscInt bs)
 {
@@ -483,14 +486,14 @@ static PetscErrorCode EPSPRIMMEGetBlockSize_PRIMME(EPS eps,PetscInt *bs)
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  bs - returned block size
 
    Level: advanced
 
-.seealso: EPSPRIMMESetBlockSize()
+.seealso: [](ch:eps), `EPSPRIMME`, `EPSPRIMMESetBlockSize()`
 @*/
 PetscErrorCode EPSPRIMMEGetBlockSize(EPS eps,PetscInt *bs)
 {
@@ -516,18 +519,20 @@ static PetscErrorCode EPSPRIMMESetMethod_PRIMME(EPS eps,EPSPRIMMEMethod method)
    Logically Collective
 
    Input Parameters:
-+  eps - the eigenproblem solver context
++  eps - the linear eigensolver context
 -  method - method that will be used by PRIMME
 
    Options Database Key:
-.  -eps_primme_method - Sets the method for the PRIMME library
+.  -eps_primme_method \<method\> - sets the method for the PRIMME library
 
-   Note:
-   If not set, the method defaults to EPS_PRIMME_DEFAULT_MIN_TIME.
+   Notes:
+   If not set, the method defaults to `EPS_PRIMME_DEFAULT_MIN_TIME`.
+
+   See the documentation of PRIMME {cite:p}`Sta10` for a description of the methods.
 
    Level: advanced
 
-.seealso: EPSPRIMMEGetMethod(), EPSPRIMMEMethod
+.seealso: [](ch:eps), `EPSPRIMME`, `EPSPRIMMEGetMethod()`, `EPSPRIMMEMethod`
 @*/
 PetscErrorCode EPSPRIMMESetMethod(EPS eps,EPSPRIMMEMethod method)
 {
@@ -553,14 +558,14 @@ static PetscErrorCode EPSPRIMMEGetMethod_PRIMME(EPS eps,EPSPRIMMEMethod *method)
    Not Collective
 
    Input Parameter:
-.  eps - the eigenproblem solver context
+.  eps - the linear eigensolver context
 
    Output Parameter:
 .  method - method that will be used by PRIMME
 
    Level: advanced
 
-.seealso: EPSPRIMMESetMethod(), EPSPRIMMEMethod
+.seealso: [](ch:eps), `EPSPRIMME`, `EPSPRIMMESetMethod()`, `EPSPRIMMEMethod`
 @*/
 PetscErrorCode EPSPRIMMEGetMethod(EPS eps,EPSPRIMMEMethod *method)
 {
@@ -571,6 +576,18 @@ PetscErrorCode EPSPRIMMEGetMethod(EPS eps,EPSPRIMMEMethod *method)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   EPSPRIMME - EPSPRIMME = "primme" - A wrapper to PRIMME {cite:p}`Sta10`.
+
+   Note:
+   The PRIMME library implements several closely related eigensolvers. The
+   default one is generally a good choice, but the user can select another
+   with `EPSPRIMMESetMethod()`.
+
+   Level: beginner
+
+.seealso: [](ch:eps), `EPS`, `EPSType`, `EPSSetType()`
+M*/
 SLEPC_EXTERN PetscErrorCode EPSCreate_PRIMME(EPS eps)
 {
   EPS_PRIMME     *primme;
