@@ -44,36 +44,45 @@ PetscErrorCode NEPComputeVectors(NEP nep)
 }
 
 /*@
-   NEPSolve - Solves the nonlinear eigensystem.
+   NEPSolve - Solves the nonlinear eigenproblem.
 
    Collective
 
    Input Parameter:
-.  nep - eigensolver context obtained from NEPCreate()
+.  nep - the nonlinear eigensolver context
 
    Options Database Keys:
-+  -nep_view - print information about the solver used
-.  -nep_view_vectors - view the computed eigenvectors
-.  -nep_view_values - view the computed eigenvalues
-.  -nep_converged_reason - print reason for convergence, and number of iterations
-.  -nep_error_absolute - print absolute errors of each eigenpair
-.  -nep_error_relative - print relative errors of each eigenpair
--  -nep_error_backward - print backward errors of each eigenpair
++  -nep_view             - print information about the solver once the solve is complete
+.  -nep_view_pre         - print information about the solver before the solve starts
+.  -nep_view_matk        - view the split form matrix $A_k$ (replace `k` by an integer from 0 to `nt`-1)
+.  -nep_view_fnk         - view the split form function $f_k$ (replace `k` by an integer from 0 to `nt`-1)
+.  -nep_view_vectors     - view the computed eigenvectors
+.  -nep_view_values      - view the computed eigenvalues
+.  -nep_converged_reason - print reason for convergence/divergence, and number of iterations
+.  -nep_error_absolute   - print absolute errors of each eigenpair
+.  -nep_error_relative   - print relative errors of each eigenpair
+-  -nep_error_backward   - print backward errors of each eigenpair
 
    Notes:
+   `NEPSolve()` will return without generating an error regardless of whether
+   all requested solutions were computed or not. Call `NEPGetConverged()` to get the
+   actual number of computed solutions, and `NEPGetConvergedReason()` to determine if
+   the solver converged or failed and why.
+
    All the command-line options listed above admit an optional argument specifying
-   the viewer type and options. For instance, use '-nep_view_vectors binary:myvecs.bin'
-   to save the eigenvectors to a binary file, '-nep_view_values draw' to draw the computed
-   eigenvalues graphically, or '-nep_error_relative :myerr.m:ascii_matlab' to save
+   the viewer type and options. For instance, use `-nep_view_vectors binary:myvecs.bin`
+   to save the eigenvectors to a binary file, `-nep_view_values draw` to draw the computed
+   eigenvalues graphically, or `-nep_error_relative :myerr.m:ascii_matlab` to save
    the errors in a file that can be executed in Matlab.
 
    Level: beginner
 
-.seealso: NEPCreate(), NEPSetUp(), NEPDestroy(), NEPSetTolerances()
+.seealso: [](ch:nep), `NEPCreate()`, `NEPSetUp()`, `NEPDestroy()`, `NEPSetTolerances()`, `NEPGetConverged()`, `NEPGetConvergedReason()`
 @*/
 PetscErrorCode NEPSolve(NEP nep)
 {
   PetscInt       i;
+  char           str[16];
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(nep,NEP_CLASSID,1);
@@ -119,6 +128,14 @@ PetscErrorCode NEPSolve(NEP nep)
   PetscCall(NEPErrorViewFromOptions(nep));
   PetscCall(NEPValuesViewFromOptions(nep));
   PetscCall(NEPVectorsViewFromOptions(nep));
+  if (nep->fui==NEP_USER_INTERFACE_SPLIT) {
+    for (i=0;i<nep->nt;i++) {
+      PetscCall(PetscSNPrintf(str,sizeof(str),"-nep_view_mat%" PetscInt_FMT,i));
+      PetscCall(MatViewFromOptions(nep->A[i],(PetscObject)nep,str));
+      PetscCall(PetscSNPrintf(str,sizeof(str),"-nep_view_fn%" PetscInt_FMT,i));
+      PetscCall(FNViewFromOptions(nep->f[i],(PetscObject)nep,str));
+    }
+  }
 
   /* Remove the initial subspace */
   nep->nini = 0;
@@ -141,16 +158,16 @@ PetscErrorCode NEPSolve(NEP nep)
    Notes:
    This is available for split operator only.
 
-   The nonlinear operator T(lambda) is projected onto span(V), where V is
+   The nonlinear operator $T(\lambda)$ is projected onto $\operatorname{span}(V)$, where $V$ is
    an orthonormal basis built internally by the solver. The projected
-   operator is equal to sum_i V'*A_i*V*f_i(lambda), so this function
-   computes all matrices Ei = V'*A_i*V, and stores them in the extra
-   matrices inside DS. Only rows/columns in the range [j0,j1-1] are computed,
+   operator is equal to $\sum_i V^* A_i V f_i(\lambda)$, so this function
+   computes all matrices $E_i = V^* A_i V$, and stores them in the extra
+   matrices inside `DS`, see `DSMatType`. Only rows/columns in the range [`j0`,`j1`-1] are computed,
    the previous ones are assumed to be available already.
 
    Level: developer
 
-.seealso: NEPSetSplitOperator()
+.seealso: [](ch:nep), `NEPSetSplitOperator()`
 @*/
 PetscErrorCode NEPProjectOperator(NEP nep,PetscInt j0,PetscInt j1)
 {
@@ -173,7 +190,7 @@ PetscErrorCode NEPProjectOperator(NEP nep,PetscInt j0,PetscInt j1)
 }
 
 /*@
-   NEPApplyFunction - Applies the nonlinear function T(lambda) to a given vector.
+   NEPApplyFunction - Applies the nonlinear function $T(\lambda)$ to a given vector.
 
    Collective
 
@@ -190,14 +207,14 @@ PetscErrorCode NEPProjectOperator(NEP nep,PetscInt j0,PetscInt j1)
 
    Note:
    If the nonlinear operator is represented in split form, the result
-   y = T(lambda)*x is computed without building T(lambda) explicitly. In
-   that case, parameters A and B are not used. Otherwise, the matrix
-   T(lambda) is built and the effect is the same as a call to
-   NEPComputeFunction() followed by a MatMult().
+   $y = T(\lambda)x$ is computed without building $T(\lambda)$ explicitly. In
+   that case, parameters `A` and `B` are not used. Otherwise, the matrix
+   $T(\lambda)$ is built and the effect is the same as a call to
+   `NEPComputeFunction()` followed by a `MatMult()`.
 
    Level: developer
 
-.seealso: NEPSetSplitOperator(), NEPComputeFunction(), NEPApplyAdjoint()
+.seealso: [](ch:nep), `NEPSetSplitOperator()`, `NEPComputeFunction()`, `NEPApplyAdjoint()`
 @*/
 PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat A,Mat B)
 {
@@ -229,7 +246,7 @@ PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 }
 
 /*@
-   NEPApplyAdjoint - Applies the adjoint nonlinear function T(lambda)^* to a given vector.
+   NEPApplyAdjoint - Applies the adjoint nonlinear function $T^*(\lambda)$ to a given vector.
 
    Collective
 
@@ -244,9 +261,16 @@ PetscErrorCode NEPApplyFunction(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 .  A   - (optional) Function matrix, for callback interface only
 -  B   - (unused) preconditioning matrix
 
+   Note:
+   If the nonlinear operator is represented in split form, the result
+   $y = T^*(\lambda)x$ is computed without building $T(\lambda)$ explicitly. In
+   that case, parameters `A` and `B` are not used. Otherwise, the matrix
+   $T(\lambda)$ is built and the effect is the same as a call to
+   `NEPComputeFunction()` followed by a `MatMultHermitianTranspose()`.
+
    Level: developer
 
-.seealso: NEPSetSplitOperator(), NEPComputeFunction(), NEPApplyFunction()
+.seealso: [](ch:nep), `NEPSetSplitOperator()`, `NEPComputeFunction()`, `NEPApplyFunction()`
 @*/
 PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat A,Mat B)
 {
@@ -270,13 +294,13 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
     PetscCall(VecSet(y,0.0));
     for (i=0;i<nep->nt;i++) {
       PetscCall(FNEvaluateFunction(nep->f[i],lambda,&alpha));
-      PetscCall(MatMultTranspose(nep->A[i],w,v));
+      PetscCall(MatMultHermitianTranspose(nep->A[i],w,v));
       PetscCall(VecAXPY(y,alpha,v));
     }
   } else {
     if (!A) A = nep->function;
     PetscCall(NEPComputeFunction(nep,lambda,A,A));
-    PetscCall(MatMultTranspose(A,w,y));
+    PetscCall(MatMultHermitianTranspose(A,w,y));
   }
   PetscCall(VecDestroy(&w));
   PetscCall(VecConjugate(y));
@@ -284,7 +308,7 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 }
 
 /*@
-   NEPApplyJacobian - Applies the nonlinear Jacobian T'(lambda) to a given vector.
+   NEPApplyJacobian - Applies the nonlinear Jacobian $T'(\lambda)$ to a given vector.
 
    Collective
 
@@ -300,14 +324,14 @@ PetscErrorCode NEPApplyAdjoint(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 
    Note:
    If the nonlinear operator is represented in split form, the result
-   y = T'(lambda)*x is computed without building T'(lambda) explicitly. In
-   that case, parameter A is not used. Otherwise, the matrix
-   T'(lambda) is built and the effect is the same as a call to
-   NEPComputeJacobian() followed by a MatMult().
+   $y = T'(\lambda)x$ is computed without building $T'(\lambda)$ explicitly. In
+   that case, parameter `A` is not used. Otherwise, the matrix
+   $T'(\lambda)$ is built and the effect is the same as a call to
+   `NEPComputeJacobian()` followed by a `MatMult()`.
 
    Level: developer
 
-.seealso: NEPSetSplitOperator(), NEPComputeJacobian()
+.seealso: [](ch:nep), `NEPSetSplitOperator()`, `NEPComputeJacobian()`
 @*/
 PetscErrorCode NEPApplyJacobian(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat A)
 {
@@ -339,7 +363,7 @@ PetscErrorCode NEPApplyJacobian(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 
 /*@
    NEPGetIterationNumber - Gets the current iteration number. If the
-   call to NEPSolve() is complete, then it returns the number of iterations
+   call to `NEPSolve()` is complete, then it returns the number of iterations
    carried out by the solution method.
 
    Not Collective
@@ -351,15 +375,15 @@ PetscErrorCode NEPApplyJacobian(NEP nep,PetscScalar lambda,Vec x,Vec v,Vec y,Mat
 .  its - number of iterations
 
    Note:
-   During the i-th iteration this call returns i-1. If NEPSolve() is
-   complete, then parameter "its" contains either the iteration number at
+   During the $i$-th iteration this call returns $i-1$. If `NEPSolve()` is
+   complete, then parameter `its` contains either the iteration number at
    which convergence was successfully reached, or failure was detected.
-   Call NEPGetConvergedReason() to determine if the solver converged or
+   Call `NEPGetConvergedReason()` to determine if the solver converged or
    failed and why.
 
    Level: intermediate
 
-.seealso: NEPGetConvergedReason(), NEPSetTolerances()
+.seealso: [](ch:nep), `NEPGetConvergedReason()`, `NEPSetTolerances()`
 @*/
 PetscErrorCode NEPGetIterationNumber(NEP nep,PetscInt *its)
 {
@@ -382,11 +406,14 @@ PetscErrorCode NEPGetIterationNumber(NEP nep,PetscInt *its)
 .  nconv - number of converged eigenpairs
 
    Note:
-   This function should be called after NEPSolve() has finished.
+   This function should be called after `NEPSolve()` has finished.
+
+   The value `nconv` may be different from the number of requested solutions
+   `nev`, but not larger than `ncv`, see `NEPSetDimensions()`.
 
    Level: beginner
 
-.seealso: NEPSetDimensions(), NEPSolve(), NEPGetEigenpair()
+.seealso: [](ch:nep), `NEPSetDimensions()`, `NEPSolve()`, `NEPGetEigenpair()`
 @*/
 PetscErrorCode NEPGetConverged(NEP nep,PetscInt *nconv)
 {
@@ -399,7 +426,7 @@ PetscErrorCode NEPGetConverged(NEP nep,PetscInt *nconv)
 }
 
 /*@
-   NEPGetConvergedReason - Gets the reason why the NEPSolve() iteration was
+   NEPGetConvergedReason - Gets the reason why the `NEPSolve()` iteration was
    stopped.
 
    Not Collective
@@ -408,26 +435,19 @@ PetscErrorCode NEPGetConverged(NEP nep,PetscInt *nconv)
 .  nep - the nonlinear eigensolver context
 
    Output Parameter:
-.  reason - negative value indicates diverged, positive value converged
+.  reason - negative value indicates diverged, positive value converged, see
+   `NEPConvergedReason` for the possible values
 
    Options Database Key:
-.  -nep_converged_reason - print the reason to a viewer
+.  -nep_converged_reason - print reason for convergence/divergence, and number of iterations
 
-   Notes:
-   Possible values for reason are
-+  NEP_CONVERGED_TOL - converged up to tolerance
-.  NEP_CONVERGED_USER - converged due to a user-defined condition
-.  NEP_DIVERGED_ITS - required more than max_it iterations to reach convergence
-.  NEP_DIVERGED_BREAKDOWN - generic breakdown in method
-.  NEP_DIVERGED_LINEAR_SOLVE - inner linear solve failed
--  NEP_DIVERGED_SUBSPACE_EXHAUSTED - run out of space for the basis in an
-   unrestarted solver
-
-   Can only be called after the call to NEPSolve() is complete.
+   Note:
+   If this routine is called before or doing the `NEPSolve()` the value of
+   `NEP_CONVERGED_ITERATING` is returned.
 
    Level: intermediate
 
-.seealso: NEPSetTolerances(), NEPSolve(), NEPConvergedReason
+.seealso: [](ch:nep), `NEPSetTolerances()`, `NEPSolve()`, `NEPConvergedReason`
 @*/
 PetscErrorCode NEPGetConvergedReason(NEP nep,NEPConvergedReason *reason)
 {
@@ -439,14 +459,14 @@ PetscErrorCode NEPGetConvergedReason(NEP nep,NEPConvergedReason *reason)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@C
-   NEPGetEigenpair - Gets the i-th solution of the eigenproblem as computed by
-   NEPSolve(). The solution consists in both the eigenvalue and the eigenvector.
+/*@
+   NEPGetEigenpair - Gets the `i`-th solution of the eigenproblem as computed by
+   `NEPSolve()`. The solution consists in both the eigenvalue and the eigenvector.
 
    Collective
 
    Input Parameters:
-+  nep - nonlinear eigensolver context
++  nep - the nonlinear eigensolver context
 -  i   - index of the solution
 
    Output Parameters:
@@ -456,23 +476,25 @@ PetscErrorCode NEPGetConvergedReason(NEP nep,NEPConvergedReason *reason)
 -  Vi   - imaginary part of eigenvector
 
    Notes:
-   It is allowed to pass NULL for Vr and Vi, if the eigenvector is not
-   required. Otherwise, the caller must provide valid Vec objects, i.e.,
-   they must be created by the calling program with e.g. MatCreateVecs().
+   It is allowed to pass `NULL` for `Vr` and `Vi`, if the eigenvector is not
+   required. Otherwise, the caller must provide valid `Vec` objects, i.e.,
+   they must be created by the calling program with e.g. `MatCreateVecs()`.
 
-   If the eigenvalue is real, then eigi and Vi are set to zero. If PETSc is
+   If the eigenvalue is real, then `eigi` and `Vi` are set to zero. If PETSc is
    configured with complex scalars the eigenvalue is stored
-   directly in eigr (eigi is set to zero) and the eigenvector in Vr (Vi is
-   set to zero). In any case, the user can pass NULL in Vr or Vi if one of
-   them is not required.
+   directly in `eigr` (`eigi` is set to zero) and the eigenvector in `Vr` (`Vi`
+   is set to zero). In any case, the user can pass `NULL` in any argument that
+   is not required.
 
-   The index i should be a value between 0 and nconv-1 (see NEPGetConverged()).
+   The index `i` should be a value between 0 and `nconv`-1 (see `NEPGetConverged()`).
    Eigenpairs are indexed according to the ordering criterion established
-   with NEPSetWhichEigenpairs().
+   with `NEPSetWhichEigenpairs()`.
+
+   The eigenvector is normalized to have unit norm.
 
    Level: beginner
 
-.seealso: NEPSolve(), NEPGetConverged(), NEPSetWhichEigenpairs(), NEPGetLeftEigenvector()
+.seealso: [](ch:nep), `NEPSolve()`, `NEPGetConverged()`, `NEPSetWhichEigenpairs()`, `NEPGetLeftEigenvector()`
 @*/
 PetscErrorCode NEPGetEigenpair(NEP nep,PetscInt i,PetscScalar *eigr,PetscScalar *eigi,Vec Vr,Vec Vi)
 {
@@ -505,12 +527,12 @@ PetscErrorCode NEPGetEigenpair(NEP nep,PetscInt i,PetscScalar *eigr,PetscScalar
 }
 
 /*@
-   NEPGetLeftEigenvector - Gets the i-th left eigenvector as computed by NEPSolve().
+   NEPGetLeftEigenvector - Gets the `i`-th left eigenvector as computed by `NEPSolve()`.
 
    Collective
 
    Input Parameters:
-+  nep - eigensolver context
++  nep - the nonlinear eigensolver context
 -  i   - index of the solution
 
    Output Parameters:
@@ -518,24 +540,24 @@ PetscErrorCode NEPGetEigenpair(NEP nep,PetscInt i,PetscScalar *eigr,PetscScalar
 -  Wi   - imaginary part of left eigenvector
 
    Notes:
-   The caller must provide valid Vec objects, i.e., they must be created
-   by the calling program with e.g. MatCreateVecs().
+   The caller must provide valid `Vec` objects, i.e., they must be created
+   by the calling program with e.g. `MatCreateVecs()`.
 
-   If the corresponding eigenvalue is real, then Wi is set to zero. If PETSc is
-   configured with complex scalars the eigenvector is stored directly in Wr
-   (Wi is set to zero). In any case, the user can pass NULL in Wr or Wi if one of
-   them is not required.
+   If the corresponding eigenvalue is real, then `Wi` is set to zero. If PETSc is
+   configured with complex scalars the eigenvector is stored directly in `Wr`
+   (`Wi` is set to zero). In any case, the user can pass `NULL` in `Wr` or `Wi` if
+   one of them is not required.
 
-   The index i should be a value between 0 and nconv-1 (see NEPGetConverged()).
+   The index `i` should be a value between 0 and `nconv`-1 (see `NEPGetConverged()`).
    Eigensolutions are indexed according to the ordering criterion established
-   with NEPSetWhichEigenpairs().
+   with `NEPSetWhichEigenpairs()`.
 
    Left eigenvectors are available only if the twosided flag was set, see
-   NEPSetTwoSided().
+   `NEPSetTwoSided()`.
 
    Level: intermediate
 
-.seealso: NEPGetEigenpair(), NEPGetConverged(), NEPSetWhichEigenpairs(), NEPSetTwoSided()
+.seealso: [](ch:nep), `NEPGetEigenpair()`, `NEPGetConverged()`, `NEPSetWhichEigenpairs()`, `NEPSetTwoSided()`
 @*/
 PetscErrorCode NEPGetLeftEigenvector(NEP nep,PetscInt i,Vec Wr,Vec Wi)
 {
@@ -557,25 +579,25 @@ PetscErrorCode NEPGetLeftEigenvector(NEP nep,PetscInt i,Vec Wr,Vec Wi)
 }
 
 /*@
-   NEPGetErrorEstimate - Returns the error estimate associated to the i-th
+   NEPGetErrorEstimate - Returns the error estimate associated to the `i`-th
    computed eigenpair.
 
    Not Collective
 
    Input Parameters:
-+  nep - nonlinear eigensolver context
++  nep - the nonlinear eigensolver context
 -  i   - index of eigenpair
 
    Output Parameter:
 .  errest - the error estimate
 
-   Notes:
+   Note:
    This is the error estimate used internally by the eigensolver. The actual
-   error bound can be computed with NEPComputeError().
+   error bound can be computed with `NEPComputeError()`.
 
    Level: advanced
 
-.seealso: NEPComputeError()
+.seealso: [](ch:nep), `NEPComputeError()`
 @*/
 PetscErrorCode NEPGetErrorEstimate(NEP nep,PetscInt i,PetscReal *errest)
 {
@@ -614,26 +636,30 @@ PetscErrorCode NEPComputeResidualNorm_Private(NEP nep,PetscBool adj,PetscScalar
 
 /*@
    NEPComputeError - Computes the error (based on the residual norm) associated
-   with the i-th computed eigenpair.
+   with the `i`-th computed eigenpair.
 
    Collective
 
    Input Parameters:
 +  nep  - the nonlinear eigensolver context
 .  i    - the solution index
--  type - the type of error to compute
+-  type - the type of error to compute, see `NEPErrorType`
 
    Output Parameter:
 .  error - the error
 
    Notes:
    The error can be computed in various ways, all of them based on the residual
-   norm computed as ||T(lambda)x||_2 where lambda is the eigenvalue and x is the
+   norm computed as $\|T(\lambda)x\|_2$ where $(\lambda,x)$ is the approximate eigenpair.
+
+   If the computation of left eigenvectors was enabled with `NEPSetTwoSided()`,
+   then the error will be computed using the maximum of the value above and
+   the left residual norm $\|y^*T(\lambda)\|_2$, where $y$ is the approximate left
    eigenvector.
 
    Level: beginner
 
-.seealso: NEPErrorType, NEPSolve(), NEPGetErrorEstimate()
+.seealso: [](ch:nep), `NEPErrorType`, `NEPSolve()`, `NEPGetErrorEstimate()`, `NEPSetTwoSided()`
 @*/
 PetscErrorCode NEPComputeError(NEP nep,PetscInt i,NEPErrorType type,PetscReal *error)
 {
@@ -718,27 +744,27 @@ PetscErrorCode NEPComputeError(NEP nep,PetscInt i,NEPErrorType type,PetscReal *e
 }
 
 /*@
-   NEPComputeFunction - Computes the function matrix T(lambda) that has been
-   set with NEPSetFunction().
+   NEPComputeFunction - Computes the function matrix $T(\lambda)$ that has been
+   set with `NEPSetFunction()`.
 
    Collective
 
    Input Parameters:
-+  nep    - the NEP context
++  nep    - the nonlinear eigensolver context
 -  lambda - the scalar argument
 
    Output Parameters:
 +  A   - Function matrix
 -  B   - optional preconditioning matrix
 
-   Notes:
-   NEPComputeFunction() is typically used within nonlinear eigensolvers
+   Note:
+   `NEPComputeFunction()` is typically used within nonlinear eigensolvers
    implementations, so most users would not generally call this routine
    themselves.
 
    Level: developer
 
-.seealso: NEPSetFunction(), NEPGetFunction()
+.seealso: [](ch:nep), `NEPSetFunction()`, `NEPGetFunction()`, `NEPComputeJacobian()`
 @*/
 PetscErrorCode NEPComputeFunction(NEP nep,PetscScalar lambda,Mat A,Mat B)
 {
@@ -769,16 +795,16 @@ PetscErrorCode NEPComputeFunction(NEP nep,PetscScalar lambda,Mat A,Mat B)
 }
 
 /*@
-   NEPComputeJacobian - Computes the Jacobian matrix T'(lambda) that has been
-   set with NEPSetJacobian().
+   NEPComputeJacobian - Computes the Jacobian matrix $T'(\lambda)$ that has been
+   set with `NEPSetJacobian()`.
 
    Collective
 
    Input Parameters:
-+  nep    - the NEP context
++  nep    - the nonlinear eigensolver context
 -  lambda - the scalar argument
 
-   Output Parameters:
+   Output Parameter:
 .  A   - Jacobian matrix
 
    Notes:
@@ -787,7 +813,7 @@ PetscErrorCode NEPComputeFunction(NEP nep,PetscScalar lambda,Mat A,Mat B)
 
    Level: developer
 
-.seealso: NEPSetJacobian(), NEPGetJacobian()
+.seealso: [](ch:nep), `NEPSetJacobian()`, `NEPGetJacobian()`, `NEPComputeFunction()`
 @*/
 PetscErrorCode NEPComputeJacobian(NEP nep,PetscScalar lambda,Mat A)
 {
