@@ -26,12 +26,13 @@ static PetscErrorCode SVDSetUp_ScaLAPACK(SVD svd)
   PetscFunctionBegin;
   SVDCheckStandard(svd);
   SVDCheckDefinite(svd);
+  if (svd->nsv==0) svd->nsv = 1;
   PetscCall(MatGetSize(svd->A,&M,&N));
   svd->ncv = N;
   if (svd->mpd!=PETSC_DETERMINE) PetscCall(PetscInfo(svd,"Warning: parameter mpd ignored\n"));
   if (svd->max_it==PETSC_DETERMINE) svd->max_it = 1;
   svd->leftbasis = PETSC_TRUE;
-  SVDCheckUnsupported(svd,SVD_FEATURE_STOPPING);
+  SVDCheckIgnored(svd,SVD_FEATURE_STOPPING);
   PetscCall(SVDAllocateSolution(svd,0));
 
   /* convert matrix */
@@ -133,6 +134,24 @@ static PetscErrorCode SVDReset_ScaLAPACK(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   SVDSCALAPACK - SVDSCALAPACK = "scalapack" - A wrapper to the ScaLAPACK
+   singular value solver {cite:p}`Bla97`.
+
+   Notes:
+   Only available for standard SVD problems, using subroutine `pdgesvd` and
+   the analogs for other precisions.
+
+   This is a direct singular value solver, that is, the full decomposition
+   is computed. The computation involves redistributing the matrices from PETSc
+   storage to ScaLAPACK distribution, and vice versa (this is done automatically
+   by SLEPc). Alternatively, the user may create the problem matrices
+   already with type `MATSCALAPACK`.
+
+   Level: beginner
+
+.seealso: [](ch:svd), `SVD`, `SVDType`, `SVDSetType()`
+M*/
 SLEPC_EXTERN PetscErrorCode SVDCreate_ScaLAPACK(SVD svd)
 {
   SVD_ScaLAPACK  *ctx;
