@@ -45,7 +45,7 @@ static PetscErrorCode SVDSetUp_Lanczos(SVD svd)
   PetscCall(MatGetSize(svd->A,NULL,&N));
   PetscCall(SVDSetDimensions_Default(svd));
   PetscCheck(svd->ncv<=svd->nsv+svd->mpd,PetscObjectComm((PetscObject)svd),PETSC_ERR_USER_INPUT,"The value of ncv must not be larger than nev+mpd");
-  if (svd->max_it==PETSC_DETERMINE) svd->max_it = PetscMax(N/svd->ncv,100);
+  if (svd->max_it==PETSC_DETERMINE) svd->max_it = PetscMax(N/svd->ncv,100)*((svd->stop==SVD_STOP_THRESHOLD)?10:1);
   svd->leftbasis = PetscNot(lanczos->oneside);
   PetscCall(SVDAllocateSolution(svd,1));
   PetscCall(DSSetType(svd->ds,DSSVD));
@@ -221,7 +221,7 @@ static PetscErrorCode SVDSolve_Lanczos(SVD svd)
 {
   SVD_LANCZOS    *lanczos = (SVD_LANCZOS*)svd->data;
   PetscReal      *alpha,*beta;
-  PetscScalar    *swork,*w,*P;
+  PetscScalar    *swork,*w,*P,*aux1,*aux2;
   PetscInt       i,k,j,nv,ld;
   Vec            u=NULL,u_1=NULL;
   Mat            U,V;
@@ -269,6 +269,7 @@ static PetscErrorCode SVDSolve_Lanczos(SVD svd)
 
     /* check convergence */
     PetscCall(SVDKrylovConvergence(svd,PETSC_FALSE,svd->nconv,nv-svd->nconv,1.0,&k));
+    SVDSetCtxThreshold(svd,svd->sigma,k);
     PetscCall((*svd->stopping)(svd,svd->its,svd->max_it,k,svd->nsv,&svd->reason,svd->stoppingctx));
 
     /* compute restart vector */
@@ -295,8 +296,21 @@ static PetscErrorCode SVDSolve_Lanczos(SVD svd)
       PetscCall(DSRestoreMat(svd->ds,DS_MAT_U,&U));
     }
 
-    /* copy restart vector from the last column */
-    if (svd->reason == SVD_CONVERGED_ITERATING) PetscCall(BVCopyColumn(svd->V,nv,k));
+    if (svd->reason == SVD_CONVERGED_ITERATING) {
+      PetscCall(BVCopyColumn(svd->V,nv,k));  /* copy restart vector from the last column */
+      if (svd->stop==SVD_STOP_THRESHOLD && nv-k<5) {  /* reallocate */
+        svd->ncv = svd->mpd+k;
+        PetscCall(SVDReallocateSolution(svd,svd->ncv+1));
+        for (i=nv;i<svd->ncv;i++) svd->perm[i] = i;
+        PetscCall(DSReallocate(svd->ds,svd->ncv+1));
+        aux1 = w;
+        aux2 = swork;
+        PetscCall(PetscMalloc2(svd->ncv+1,&w,svd->ncv,&swork));
+        PetscCall(PetscArraycpy(w,aux1,ld));
+        PetscCall(PetscFree2(aux1,aux2));
+        PetscCall(DSGetLeadingDimension(svd->ds,&ld));
+      }
+    }
 
     svd->nconv = k;
     PetscCall(SVDMonitor(svd,svd->its,svd->nconv,svd->sigma,svd->errest,nv));
@@ -309,7 +323,7 @@ static PetscErrorCode SVDSolve_Lanczos(SVD svd)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode SVDSetFromOptions_Lanczos(SVD svd,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode SVDSetFromOptions_Lanczos(SVD svd,PetscOptionItems PetscOptionsObject)
 {
   PetscBool      set,val;
   SVD_LANCZOS    *lanczos = (SVD_LANCZOS*)svd->data;
@@ -343,21 +357,22 @@ static PetscErrorCode SVDLanczosSetOneSide_Lanczos(SVD svd,PetscBool oneside)
    Logically Collective
 
    Input Parameters:
-+  svd     - singular value solver
++  svd     - the singular value solver context
 -  oneside - boolean flag indicating if the method is one-sided or not
 
    Options Database Key:
-.  -svd_lanczos_oneside <boolean> - Indicates the boolean flag
+.  -svd_lanczos_oneside - enable the one-sided variant
 
    Note:
    By default, a two-sided variant is selected, which is sometimes slightly
    more robust. However, the one-sided variant is faster because it avoids
    the orthogonalization associated to left singular vectors. It also saves
-   the memory required for storing such vectors.
+   the memory required for storing such vectors. See more details in
+   {cite:p}`Her07c,Her08`.
 
    Level: advanced
 
-.seealso: SVDTRLanczosSetOneSide()
+.seealso: [](ch:svd), `SVDTRLANCZOS`, `SVDTRLanczosSetOneSide()`
 @*/
 PetscErrorCode SVDLanczosSetOneSide(SVD svd,PetscBool oneside)
 {
@@ -383,15 +398,15 @@ static PetscErrorCode SVDLanczosGetOneSide_Lanczos(SVD svd,PetscBool *oneside)
 
    Not Collective
 
-   Input Parameters:
-.  svd     - singular value solver
+   Input Parameter:
+.  svd - the singular value solver context
 
-   Output Parameters:
+   Output Parameter:
 .  oneside - boolean flag indicating if the method is one-sided or not
 
    Level: advanced
 
-.seealso: SVDLanczosSetOneSide()
+.seealso: [](ch:svd), `SVDTRLANCZOS`, `SVDLanczosSetOneSide()`
 @*/
 PetscErrorCode SVDLanczosGetOneSide(SVD svd,PetscBool *oneside)
 {
@@ -422,6 +437,27 @@ static PetscErrorCode SVDView_Lanczos(SVD svd,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   SVDLANCZOS - SVDLANCZOS = "lanczos" - A basic Golub-Kahan-Lanczos
+   bidiagonalization method with explicit restart.
+
+   Notes:
+   Only available for standard SVD problems.
+
+   This solver is very basic and is not recommended in general, since it
+   will not be competitive with respect to other solvers.
+
+   The implemented method is Lanczos bidiagonalization with explicit restart
+   and deflation. Generally, it is much better to use Lanczos with implicit
+   restart (also known as thick-restart Lanczos) as implemented in `SVDTRLANCZOS`.
+
+   The implementation includes a one-sided orthogonalization option, and
+   efficient parallel orthogonalization, see the details in {cite:p}`Her07c,Her08`.
+
+   Level: beginner
+
+.seealso: [](ch:svd), [](#sec:svdback), `SVD`, `SVDType`, `SVDSetType()`, `SVDSetProblemType()`, `SVDTRLANCZOS`
+M*/
 SLEPC_EXTERN PetscErrorCode SVDCreate_Lanczos(SVD svd)
 {
   SVD_LANCZOS    *ctx;
