@@ -8,7 +8,7 @@
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-static char help[] = "Computes a partial generalized singular value decomposition (GSVD).\n"
+static char help[] = "Computes a partial generalized singular value decomposition (GSVD).\n\n"
   "The command line options are:\n"
   "  -m <m>, where <m> = number of rows of A.\n"
   "  -n <n>, where <n> = number of columns of A.\n"
@@ -28,7 +28,7 @@ int main(int argc,char **argv)
   PetscBool      flg,skiporth=PETSC_FALSE;
 
   PetscFunctionBeginUser;
-  PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
+  PetscCall(SlepcInitialize(&argc,&argv,NULL,help));
 
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-m",&m,NULL));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&n,&flg));
