@@ -437,7 +437,7 @@ static inline PetscErrorCode BVVecsSetVmip(BV bv,PetscInt vmip)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode BVSetFromOptions_Vecs(BV bv,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode BVSetFromOptions_Vecs(BV bv,PetscOptionItems PetscOptionsObject)
 {
   BV_VECS        *ctx = (BV_VECS*)bv->data;
 
@@ -499,6 +499,15 @@ static PetscErrorCode BVDuplicate_Vecs(BV V,BV W)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   BVVECS - BVVECS = "vecs" - A basis vectors object represented by an array of
+   independent `Vec`s.
+
+   Level: beginner
+
+.seealso: [](sec:bv), `BV`, `BVType`, `BVSetType()`
+M*/
+
 SLEPC_EXTERN PetscErrorCode BVCreate_Vecs(BV bv)
 {
   BV_VECS        *ctx;
