@@ -17,13 +17,13 @@ SLEPC_EXTERN PetscErrorCode BVCreate_Mat(BV);
 SLEPC_EXTERN PetscErrorCode BVCreate_Tensor(BV);
 
 /*@C
-   BVRegisterAll - Registers all of the storage variants in the BV package.
+   BVRegisterAll - Registers all of the storage variants in the `BV` package.
 
    Not Collective
 
    Level: advanced
 
-.seealso: BVRegister()
+.seealso: [](sec:bv), `BVRegister()`
 @*/
 PetscErrorCode BVRegisterAll(void)
 {
