@@ -30,7 +30,7 @@ int main(int argc,char **argv)
 #endif
 
   PetscFunctionBeginUser;
-  PetscCall(SlepcInitialize(&argc,&argv,(char*)0,help));
+  PetscCall(SlepcInitialize(&argc,&argv,NULL,help));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-n",&n,NULL));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-k",&k,NULL));
   PetscCall(PetscOptionsGetInt(NULL,NULL,"-l",&l,NULL));
@@ -192,6 +192,10 @@ int main(int argc,char **argv)
          suffix: 1_cuda
          args: -bv_type {{svec mat}} -vec_type cuda
          requires: cuda
+      test:
+         suffix: 1_hip
+         args: -bv_type {{svec mat}} -vec_type hip
+         requires: hip
 
    testset:
       args: -n 250 -l 6 -k 15
@@ -205,5 +209,9 @@ int main(int argc,char **argv)
          suffix: 1_cuda_complex
          args: -bv_type {{svec mat}} -vec_type cuda
          requires: cuda
+      test:
+         suffix: 1_hip_complex
+         args: -bv_type {{svec mat}} -vec_type hip
+         requires: hip
 
 TEST*/
