@@ -14,7 +14,7 @@
 #include <slepc/private/fnimpl.h>      /*I "slepcfn.h" I*/
 #include <slepcblaslapack.h>
 
-PetscErrorCode FNEvaluateFunction_Log(FN fn,PetscScalar x,PetscScalar *y)
+static PetscErrorCode FNEvaluateFunction_Log(FN fn,PetscScalar x,PetscScalar *y)
 {
   PetscFunctionBegin;
 #if !defined(PETSC_USE_COMPLEX)
@@ -24,7 +24,7 @@ PetscErrorCode FNEvaluateFunction_Log(FN fn,PetscScalar x,PetscScalar *y)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNEvaluateDerivative_Log(FN fn,PetscScalar x,PetscScalar *y)
+static PetscErrorCode FNEvaluateDerivative_Log(FN fn,PetscScalar x,PetscScalar *y)
 {
   PetscFunctionBegin;
   PetscCheck(x!=0.0,PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Derivative not defined in the requested value");
@@ -290,7 +290,7 @@ static PetscScalar powerm2by2(PetscScalar A11,PetscScalar A22,PetscScalar A12,Pe
 #if defined(PETSC_USE_COMPLEX)
     w += PETSC_i*PETSC_PI*unwinding(loga2-loga1);
 #endif
-    dd = 2.0*PetscExpScalar(p*(loga1+loga2)/2.0)*PetscSinhScalar(p*w)/(a2-a1);
+    dd = 2.0*PetscExpScalar((loga1+loga2)*p/2.0)*PetscSinhScalar(p*w)/(a2-a1);
     x12 = A12*dd;
   }
   PetscFunctionReturn(x12);
@@ -440,7 +440,7 @@ static PetscErrorCode gauss_legendre(PetscBLASInt n,PetscScalar *x,PetscScalar *
 static PetscErrorCode pade_approx(PetscBLASInt n,PetscScalar *T,PetscScalar *L,PetscBLASInt ld,PetscInt m,PetscScalar *work)
 {
   PetscScalar    *K,*W,*nodes,*wts;
-  PetscBLASInt   *ipiv,info;
+  PetscBLASInt   *ipiv,info,mm;
   PetscInt       i,j,k;
 
   PetscFunctionBegin;
@@ -449,7 +449,8 @@ static PetscErrorCode pade_approx(PetscBLASInt n,PetscScalar *T,PetscScalar *L,P
   nodes = work+2*n*n;
   wts   = work+2*n*n+m;
   ipiv  = (PetscBLASInt*)(work+2*n*n+2*m);
-  PetscCall(gauss_legendre(m,nodes,wts,L));
+  PetscCall(PetscBLASIntCast(m,&mm));
+  PetscCall(gauss_legendre(mm,nodes,wts,L));
   /* Convert from [-1,1] to [0,1] */
   for (i=0;i<m;i++) {
     nodes[i] = (nodes[i]+1.0)/2.0;
@@ -604,7 +605,7 @@ static PetscErrorCode FNLogmPade(FN fn,PetscBLASInt n,PetscScalar *T,PetscBLASIn
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNEvaluateFunctionMat_Log_Higham(FN fn,Mat A,Mat B)
+static PetscErrorCode FNEvaluateFunctionMat_Log_Higham(FN fn,Mat A,Mat B)
 {
   PetscBLASInt   n = 0;
   PetscScalar    *T;
@@ -620,7 +621,7 @@ PetscErrorCode FNEvaluateFunctionMat_Log_Higham(FN fn,Mat A,Mat B)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNEvaluateFunctionMatVec_Log_Higham(FN fn,Mat A,Vec v)
+static PetscErrorCode FNEvaluateFunctionMatVec_Log_Higham(FN fn,Mat A,Vec v)
 {
   PetscBLASInt   n = 0;
   PetscScalar    *T;
@@ -639,7 +640,7 @@ PetscErrorCode FNEvaluateFunctionMatVec_Log_Higham(FN fn,Mat A,Vec v)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNView_Log(FN fn,PetscViewer viewer)
+static PetscErrorCode FNView_Log(FN fn,PetscViewer viewer)
 {
   PetscBool      isascii;
   char           str[50];
@@ -673,6 +674,14 @@ PetscErrorCode FNView_Log(FN fn,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   FNLOG - FNLOG = "log" - The logarithm function $f(x)=\log x$.
+
+   Level: beginner
+
+.seealso: [](sec:fn), `FN`, `FNType`, `FNSetType()`
+M*/
+
 SLEPC_EXTERN PetscErrorCode FNCreate_Log(FN fn)
 {
   PetscFunctionBegin;
