@@ -26,7 +26,7 @@ typedef struct {
 
 static const PetscReal rfactorial[MAX_INDEX+2] = { 1, 1, 0.5, 1.0/6, 1.0/24, 1.0/120, 1.0/720, 1.0/5040, 1.0/40320, 1.0/362880, 1.0/3628800, 1.0/39916800 };
 
-PetscErrorCode FNEvaluateFunction_Phi(FN fn,PetscScalar x,PetscScalar *y)
+static PetscErrorCode FNEvaluateFunction_Phi(FN fn,PetscScalar x,PetscScalar *y)
 {
   FN_PHI      *ctx = (FN_PHI*)fn->data;
   PetscInt    i;
@@ -42,7 +42,7 @@ PetscErrorCode FNEvaluateFunction_Phi(FN fn,PetscScalar x,PetscScalar *y)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNEvaluateDerivative_Phi(FN fn,PetscScalar x,PetscScalar *y)
+static PetscErrorCode FNEvaluateDerivative_Phi(FN fn,PetscScalar x,PetscScalar *y)
 {
   FN_PHI      *ctx = (FN_PHI*)fn->data;
   PetscInt    i;
@@ -58,7 +58,7 @@ PetscErrorCode FNEvaluateDerivative_Phi(FN fn,PetscScalar x,PetscScalar *y)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNEvaluateFunctionMatVec_Phi(FN fn,Mat A,Vec v)
+static PetscErrorCode FNEvaluateFunctionMatVec_Phi(FN fn,Mat A,Vec v)
 {
   FN_PHI            *ctx = (FN_PHI*)fn->data;
   PetscInt          i,j,m,n,nh;
@@ -122,7 +122,7 @@ static PetscErrorCode FNPhiSetIndex_Phi(FN fn,PetscInt k)
 }
 
 /*@
-   FNPhiSetIndex - Sets the index of the phi-function.
+   FNPhiSetIndex - Sets the index of the $\varphi$-function.
 
    Logically Collective
 
@@ -131,16 +131,17 @@ static PetscErrorCode FNPhiSetIndex_Phi(FN fn,PetscInt k)
 -  k  - the index
 
    Notes:
-   The phi-functions are defined as follows. The default is k=1.
-.vb
-      phi_0(x) = exp(x)
-      phi_1(x) = (exp(x)-1)/x
-      phi_k(x) = (phi_{k-1}(x)-1/(k-1)!)/x
-.ve
+   The $\varphi$-functions are defined as
+   $$\begin{align}
+     \varphi_0(x)&=e^x,\\
+     \varphi_1(x)&=\frac{e^x-1}{x},\\
+     \varphi_k(x)&=\frac{\varphi_{k-1}(x)-1/(k-1)!}{x}.
+   \end{align}$$
+   The default index is $k=1$.
 
    Level: intermediate
 
-.seealso: FNPhiGetIndex()
+.seealso: [](sec:fn), `FNPHI`, `FNPhiGetIndex()`
 @*/
 PetscErrorCode FNPhiSetIndex(FN fn,PetscInt k)
 {
@@ -161,7 +162,7 @@ static PetscErrorCode FNPhiGetIndex_Phi(FN fn,PetscInt *k)
 }
 
 /*@
-   FNPhiGetIndex - Gets the index of the phi-function.
+   FNPhiGetIndex - Gets the index of the $\varphi$-function.
 
    Not Collective
 
@@ -173,18 +174,18 @@ static PetscErrorCode FNPhiGetIndex_Phi(FN fn,PetscInt *k)
 
    Level: intermediate
 
-.seealso: FNPhiSetIndex()
+.seealso: [](sec:fn), `FNPHI`, `FNPhiSetIndex()`
 @*/
 PetscErrorCode FNPhiGetIndex(FN fn,PetscInt *k)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(fn,FN_CLASSID,1);
-  PetscValidIntPointer(k,2);
+  PetscAssertPointer(k,2);
   PetscUseMethod(fn,"FNPhiGetIndex_C",(FN,PetscInt*),(fn,k));
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNView_Phi(FN fn,PetscViewer viewer)
+static PetscErrorCode FNView_Phi(FN fn,PetscViewer viewer)
 {
   FN_PHI         *ctx = (FN_PHI*)fn->data;
   PetscBool      isascii;
@@ -212,7 +213,7 @@ PetscErrorCode FNView_Phi(FN fn,PetscViewer viewer)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNSetFromOptions_Phi(FN fn,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode FNSetFromOptions_Phi(FN fn,PetscOptionItems PetscOptionsObject)
 {
   FN_PHI         *ctx = (FN_PHI*)fn->data;
   PetscInt       k;
@@ -228,7 +229,7 @@ PetscErrorCode FNSetFromOptions_Phi(FN fn,PetscOptionItems *PetscOptionsObject)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNDuplicate_Phi(FN fn,MPI_Comm comm,FN *newfn)
+static PetscErrorCode FNDuplicate_Phi(FN fn,MPI_Comm comm,FN *newfn)
 {
   FN_PHI *ctx = (FN_PHI*)fn->data,*ctx2 = (FN_PHI*)(*newfn)->data;
 
@@ -237,7 +238,7 @@ PetscErrorCode FNDuplicate_Phi(FN fn,MPI_Comm comm,FN *newfn)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode FNDestroy_Phi(FN fn)
+static PetscErrorCode FNDestroy_Phi(FN fn)
 {
   FN_PHI         *ctx = (FN_PHI*)fn->data;
 
@@ -250,6 +251,24 @@ PetscErrorCode FNDestroy_Phi(FN fn)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+   FNPHI - FNPHI = "phi" - One of the $\varphi$-functions $\varphi_0(x)$, $\varphi_1(x)$, ...,
+   where the index of the $\varphi$-function is specified with `FNPhiSetIndex()`.
+
+   Level: beginner
+
+   Notes:
+   The $\varphi$-functions are defined as
+   $$\begin{align}
+     \varphi_0(x)&=e^x,\\
+     \varphi_1(x)&=\frac{e^x-1}{x},\\
+     \varphi_k(x)&=\frac{\varphi_{k-1}(x)-1/(k-1)!}{x}.
+   \end{align}$$
+   The default index is $k=1$.
+
+.seealso: [](sec:fn), `FN`, `FNType`, `FNSetType()`, `FNPhiSetIndex()`
+M*/
+
 SLEPC_EXTERN PetscErrorCode FNCreate_Phi(FN fn)
 {
   FN_PHI         *ctx;
