@@ -8,17 +8,15 @@
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 */
 
-#include <petsc/private/fortranimpl.h>
+#include <petsc/private/ftnimpl.h>
 #include <slepcst.h>
 
 #if defined(PETSC_HAVE_FORTRAN_CAPS)
-#define stshellgetcontext_                 STSHELLGETCONTEXT
 #define stshellsetapply_                   STSHELLSETAPPLY
 #define stshellsetapplytranspose_          STSHELLSETAPPLYTRANSPOSE
 #define stshellsetapplyhermitiantranspose_ STSHELLSETAPPLYHERMITIANTRANSPOSE
 #define stshellsetbacktransform_           STSHELLSETBACKTRANSFORM
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
-#define stshellgetcontext_                 stshellgetcontext
 #define stshellsetapply_                   stshellsetapply
 #define stshellsetapplytranspose_          stshellsetapplytranspose
 #define stshellsetapplyhermitiantranspose_ stshellsetapplyhermitiantranspose
@@ -53,31 +51,26 @@ static PetscErrorCode ourshellbacktransform(ST st,PetscInt n,PetscScalar *eigr,P
   PetscObjectUseFortranCallback(st,_cb.backtransform,(ST*,PetscInt*,PetscScalar*,PetscScalar*,PetscErrorCode*),(&st,&n,eigr,eigi,&ierr));
 }
 
-SLEPC_EXTERN void stshellgetcontext_(ST *st,void **ctx,PetscErrorCode *ierr)
+SLEPC_EXTERN void stshellsetapply_(ST *st,void (*apply)(ST*,Vec*,Vec*,PetscErrorCode*),PetscErrorCode *ierr)
 {
-  *ierr = STShellGetContext(*st,ctx);
-}
-
-SLEPC_EXTERN void stshellsetapply_(ST *st,void (*apply)(void*,Vec*,Vec*,PetscErrorCode*),PetscErrorCode *ierr)
-{
-  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.apply,(PetscVoidFunction)apply,NULL); if (*ierr) return;
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.apply,(PetscFortranCallbackFn*)apply,NULL); if (*ierr) return;
   *ierr = STShellSetApply(*st,ourshellapply);
 }
 
-SLEPC_EXTERN void stshellsetapplytranspose_(ST *st,void (*applytranspose)(void*,Vec*,Vec*,PetscErrorCode*),PetscErrorCode *ierr)
+SLEPC_EXTERN void stshellsetapplytranspose_(ST *st,void (*applytranspose)(ST*,Vec*,Vec*,PetscErrorCode*),PetscErrorCode *ierr)
 {
-  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.applytranspose,(PetscVoidFunction)applytranspose,NULL); if (*ierr) return;
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.applytranspose,(PetscFortranCallbackFn*)applytranspose,NULL); if (*ierr) return;
   *ierr = STShellSetApplyTranspose(*st,ourshellapplytranspose);
 }
 
-SLEPC_EXTERN void stshellsetapplyhermitiantranspose_(ST *st,void (*applyhermtrans)(void*,Vec*,Vec*,PetscErrorCode*),PetscErrorCode *ierr)
+SLEPC_EXTERN void stshellsetapplyhermitiantranspose_(ST *st,void (*applyhermtrans)(ST*,Vec*,Vec*,PetscErrorCode*),PetscErrorCode *ierr)
 {
-  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.applyhermtrans,(PetscVoidFunction)applyhermtrans,NULL); if (*ierr) return;
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.applyhermtrans,(PetscFortranCallbackFn*)applyhermtrans,NULL); if (*ierr) return;
   *ierr = STShellSetApplyHermitianTranspose(*st,ourshellapplyhermitiantranspose);
 }
 
-SLEPC_EXTERN void stshellsetbacktransform_(ST *st,void (*backtransform)(void*,PetscScalar*,PetscScalar*,PetscErrorCode*),PetscErrorCode *ierr)
+SLEPC_EXTERN void stshellsetbacktransform_(ST *st,void (*backtransform)(ST*,PetscScalar*,PetscScalar*,PetscErrorCode*),PetscErrorCode *ierr)
 {
-  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.backtransform,(PetscVoidFunction)backtransform,NULL); if (*ierr) return;
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*st,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.backtransform,(PetscFortranCallbackFn*)backtransform,NULL); if (*ierr) return;
   *ierr = STShellSetBackTransform(*st,ourshellbacktransform);
 }
